Learn R Programming

phenocamr (version 1.1.5)

list_sites: List all site meta-data

Description

The site list can be helpful in determining which time series to download using `download_phenocam()`. The site list also includes meta-data concerning plant functional types, general climatological conditions such as mean annual temperature or geographic location.

Usage

list_sites(out_dir = tempdir(), internal = TRUE)

Value

A data frame with meta-data for all available sites.

Arguments

out_dir

output directory (default = tempdir())

internal

TRUE or FALSE (default = TRUE)

Examples

Run this code

if (FALSE) {
# download the site meta-data
df <- list_sites()
}

Run the code above in your browser using DataLab