The site list can be helpful in determining which time series to download
using `download_phenocam()`. The site list also includes meta-data
concerning plant functional types, general climatological
conditions such as mean annual temperature or geographic location.
Usage
list_sites(out_dir = tempdir(), internal = TRUE)
Value
A data frame with meta-data for all available sites.